<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="515"/>
        <source>Playlist</source>
        <translation type="unfinished">Spilleliste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="370"/>
        <source>Artist</source>
        <translation type="unfinished">Artist</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Album</source>
        <translation type="unfinished">Album</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Rating</source>
        <translation type="unfinished">Rangering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <location filename="../mainwindow.ui" line="520"/>
        <source>Search</source>
        <translation type="unfinished">Søk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Username</source>
        <translation type="unfinished">Brukernavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>Password</source>
        <translation type="unfinished">Passord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="obsolete">Vis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Title</source>
        <translation type="unfinished">Tittel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation type="obsolete">Spill/Pause</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="75"/>
        <source>Incorrect credentials entered
please try again.</source>
        <translation type="unfinished">Ugyldig brukernavn eller passord, vennligst prøv igjen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="70"/>
        <source>Authenticating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Updating playlists...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="102"/>
        <location filename="../mainwindow.cpp" line="113"/>
        <source>Select playlist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
